//@AterCattus
import java.io.IOException;
import java.util.Arrays;

class Glonass
{
    /**
     * Общая длина исходной последовательности
     */
    private static final int SRC_BUF_SIZE = 1000 * 1000;

    /**
     * Множитель частоты приемника по сравнению с частотой источника
     */
    private static final int DST_REP_MULT = 10;

    /**
     * Коэффициент пересчета отставания сигнала в расстояние до спутника
     */
    private static final double OFFS2DISTANCE = (double)299792458 / SRC_BUF_SIZE;

    /**
     * Для оптимизации скорости работы формирую только уникальный для исходной последовательности префикс
     *
     * Это экономит порядка 400-500мс на средненьком процессоре
     */
    private static final byte[] src = new byte[]{1,1,1,0,0,1,1,0, 0,0,1,1,1,0,1,1, 0,1};

    /**
     * Максимальное удаление местоположения о начала координат, при котором оно еще считается корректным (метры)
     */
    private static final double EARTH_RADIUS = 6378000;

    /**
     * Максимально допустимая погрешность рассчета положения
     *
     * Является критерием кластеризации потенциальных местоположений
     */
    private static final double PRECISION_EPSILON = 1000;

    private static final byte B_0 = (byte)'0';
    private static final byte B_1 = (byte)'1';
    private static final byte B_n = (byte)'\n';
    private static final byte B_r = (byte)'\r';

    private static byte[] stdin;
    private static int stdinIdx = 0;

    private static SatelliteInfo[] satelliteInfos;

    /**
     * Чтение X и Y одного спутника и расчет длины фрагмента первого бита передачи
     *
     * Расстояние до спутника не рассчитывается
     */
    private static SatelliteInfo readSatelliteInfo()
    {
        final double x = Double.parseDouble(readString(lookNL(30)));
        skipNL();
        final double y = Double.parseDouble(readString(lookNL(30)));
        skipNL();

        // выяснение, сколько символов в начале буфера являются остатком частично переданного первого бита
        final byte firstBit = (byte)(stdin[stdinIdx] - B_0);

        int dstBitOffs = lookAhead(firstBit == 1 ? B_0 : B_1, SRC_BUF_SIZE) - stdinIdx;
        dstBitOffs = dstBitOffs - (int)Math.floor(dstBitOffs/DST_REP_MULT) * DST_REP_MULT;

        final int stdinOffs = stdinIdx;

        // пропускаю саму передачу. их обработка распараллеливается
        stdinIdx += SRC_BUF_SIZE * DST_REP_MULT;
        skipNL();

        return new SatelliteInfo(
                x,
                y,
                firstBit,
                dstBitOffs,
                stdinOffs
        );
    }

    /**
     * @param dst Принятая последовательность (на частоте 1кк)
     *
     * @return С какого бита последовательности начинается оригинальная последовательность
     */
    private static int resolveOffset(final byte[] dst)
    {
        final int srcLen = src.length;
        for (int i = 0; i < SRC_BUF_SIZE; ++i) {
            boolean equal = true;
            for (int j = 0; j < srcLen; ++j) {
                if (src[j] != dst[i + j]) {
                    equal = false;
                    break;
                }
            }

            if (equal) {
                return i;
            }
        }

        return -1;
    }

    /**
     * Расчет двух точек пересечения сигналов от двух спутников
     *
     * @return Массив 4х элементов {x1, y1, x2, y2} или пустой массив при ошибках (окружности не пересекаются, вложены)
     */
    private static double[] circlesIntersect(final SatelliteInfo s0, final SatelliteInfo s1)
    {
        final double
                s0x = s0.x,
                s0y = s0.y,
                s0r = s0.distance,
                s1x = s1.x,
                s1y = s1.y,
                s1r = s1.distance,
                d   = Math.sqrt(Math.pow(s0x - s1x, 2) + Math.pow(s0y - s1y, 2));

        if ((d > s0r + s1r) || (d < Math.abs(s0r - s1r))) {
            return new double[]{};
        }

        final double
                a   = (s0r*s0r - s1r*s1r + d*d) / (2*d),
                h   = Math.sqrt(s0r*s0r - a*a),
                px  = s0x + a * (s1x - s0x) / d,
                py  = s0y + a * (s1y - s0y) / d,
                hd  = h / d,
                hdx = hd * (s1y - s0y),
                hdy = hd * (s1x - s0x),
                x1  = px + hdx,
                y1  = py - hdy,
                x2  = px - hdx,
                y2  = py + hdy;

        return new double[]{x1, y1, x2, y2};
    }

    /**
     * Среди всех переданных точек находит наибольший кластер и вычисляет его центр
     *
     * @param points    Массив точек вида {{x, y}, {x, y}, ...}
     * @param pointsCnt Число заданных точек в массиве (points может быть заполнен не полностью)
     *
     * @return Массив 2х элементов {x, y} с координатами центра
     */
    private static double[] searchCenter(final double[][] points, final int pointsCnt)
    {
        final Cluster[] clusters = new Cluster[pointsCnt];
        int clusterCnt = 0;
        int maxCntInCluster = 1;

        for (int pointIdx = 0; pointIdx < pointsCnt; ++pointIdx) {
            final int x = (int)Math.round(points[pointIdx][0] / PRECISION_EPSILON);
            final int y = (int)Math.round(points[pointIdx][1] / PRECISION_EPSILON);

            boolean found = false;
            for (int clusterIdx = 0; clusterIdx < clusterCnt; ++clusterIdx) {
                if (x == clusters[clusterIdx].x && y == clusters[clusterIdx].y) {
                    found = true;
                    maxCntInCluster = Math.max(maxCntInCluster, ++clusters[clusterIdx].cnt);
                    break;
                }
            }

            if (!found) {
                clusters[clusterCnt] = new Cluster(x, y);
                ++clusterCnt;
            }
        }

        int avgX = 0, avgY = 0;

        for (int clusterIdx = 0; clusterIdx < clusterCnt; ++clusterIdx) {
            if (clusters[clusterIdx].cnt == maxCntInCluster) {
                avgX = clusters[clusterIdx].x;
                avgY = clusters[clusterIdx].y;
                break;
            }
        }

        double sumX = 0, sumY = 0;

        for (int pointIdx = 0; pointIdx < pointsCnt; ++pointIdx) {
            final int x = (int)Math.round(points[pointIdx][0] / PRECISION_EPSILON);
            final int y = (int)Math.round(points[pointIdx][1] / PRECISION_EPSILON);

            if (x == avgX && y == avgY) {
                sumX += points[pointIdx][0];
                sumY += points[pointIdx][1];
            }
        }

        return new double[]{
                sumX / maxCntInCluster,
                sumY / maxCntInCluster
        };
    }

    private static int lookAhead(final byte needle, final int limit)
    {
        final int posLimit = Math.min(stdinIdx + limit, stdin.length);
        for (int pos = stdinIdx; pos < posLimit; ++pos)
        {
            if (stdin[pos] == needle) {
                return pos;
            }
        }
        return -1;
    }

    private static int lookNL(final int limit)
    {
        final int B_np = lookAhead(B_n, limit);
        final int B_rp = lookAhead(B_r, limit);
        return (B_rp < 0) ? B_np : ((B_np < 0) ? B_rp : Math.min(B_np, B_rp));
    }

    private static String readString(final int to)
    {
        final String res = new String(Arrays.copyOfRange(stdin, stdinIdx, to));
        stdinIdx = to;
        return res;
    }

    private static void skipNL()
    {
        while (stdinIdx < stdin.length) {
            final byte ch = stdin[stdinIdx];
            if (ch == B_n || ch == B_r) {
                ++stdinIdx;
            }
            else {
                break;
            }
        }
    }

    /**
     * Разбор полученной 10кк последовательности и расчет по ней расстояния до спутника
     *
     * @param si Сведения о спутнике, полученные из readSatelliteInfo()
     */
    private static void processTransmission(final SatelliteInfo si)
    {
        si.dst = new byte[SRC_BUF_SIZE + src.length];

        int pos = si.stdinOffs + si.dstBitOffs;
        int len = SRC_BUF_SIZE;
        if (si.dstBitOffs > 0) {
            si.dst[SRC_BUF_SIZE-1] = si.firstBit;
            --len;
        }

        // чтение только "полных" бит
        for (int chunk = 0; chunk < len; ++chunk, pos += DST_REP_MULT) {
            si.dst[chunk] = (byte)(stdin[pos] - B_0);
        }

        // чтобы не обрабатывать "зацикленность" последовательности
        System.arraycopy(si.dst, 0, si.dst, SRC_BUF_SIZE, src.length);

        final double offset = resolveOffset(si.dst) + (double)si.dstBitOffs / DST_REP_MULT;

        si.distance = OFFS2DISTANCE * offset;
    }

    /**
     * Разбор всех полученных 10кк последовательностей
     */
    private static void processTransmissions()
    {
        final int satelliteCnt = satelliteInfos.length;
        final int vcpus = Runtime.getRuntime().availableProcessors();

        // vcpus * 1.5 - эмпирически. негде проверить под HT
        final int threadCnt = (satelliteCnt <= vcpus * 1.5) ? satelliteCnt : vcpus;
        final Thread[] threads = new Thread[threadCnt];

        for (int th = 0; th < threadCnt; ++th) {
            final int th_ = th;
            threads[th] = new Thread(new Runnable() {
                @Override
                public void run()
                {
                    for (int satellite = th_; satellite < satelliteCnt; satellite += threadCnt) {
                        processTransmission(satelliteInfos[satellite]);
                    }
                }
            });

            threads[th].start();
        }

        try {
            for (final Thread th : threads) {
                th.join();
            }
        }
        catch (InterruptedException ignore) {
        }
    }

    public static void main(String[] args)
    {
        try {
            stdin = new byte[System.in.available()]; // доверие :)
            //noinspection ResultOfMethodCallIgnored
            System.in.read(stdin);
        }
        catch (IOException ignore) {
            return;
        }

        final int satelliteCnt = Integer.parseInt(readString(lookNL(5)));
        skipNL();

        satelliteInfos = new SatelliteInfo[satelliteCnt];
        for (int satellite = 0; satellite < satelliteCnt; ++satellite) {
            satelliteInfos[satellite] = readSatelliteInfo();
        }

        processTransmissions();

        final double[][] points = new double[satelliteCnt*satelliteCnt][2];
        int pointIdx = 0;

        for (int sat0 = 0; sat0 < satelliteCnt; ++sat0) {
            for (int sat1 = sat0 + 1; sat1 < satelliteCnt; ++sat1) {
                final double[] _points = circlesIntersect(satelliteInfos[sat0], satelliteInfos[sat1]);

                for (int i = 0; i < _points.length; i += 2) {
                    final double d = Math.sqrt(Math.pow(_points[i], 2) + Math.pow(_points[i + 1], 2));
                    if (d > EARTH_RADIUS) {
                        continue;
                    }

                    points[pointIdx][0] = _points[i];
                    points[pointIdx][1] = _points[i+1];
                    ++pointIdx;
                }
            }
        }

        final double[] result = searchCenter(points, pointIdx);
        System.out.format("%.4f %.4f\n", result[0], result[1]);
    }

    static class SatelliteInfo
    {
        public final double x;
        public final double y;
        public final byte firstBit;
        public final int dstBitOffs;
        public final int stdinOffs;

        public byte[] dst;
        public double distance;

        public SatelliteInfo(final double x, final double y, final byte firstBit, final int dstBitOffs,
                             final int stdinOffs
        ) {
            this.x = x;
            this.y = y;
            this.firstBit   = firstBit;
            this.dstBitOffs = dstBitOffs;
            this.stdinOffs  = stdinOffs;

            this.dst = null;
            this.distance = 0;
        }
    }

    static class Cluster
    {
        public final int x;
        public final int y;
        public int cnt;

        public Cluster(final int x, final int y)
        {
            this.x = x;
            this.y = y;
            this.cnt = 1;
        }
    }
}
/*
# for i in {1..1000}; do f=`date +%s.%N`; java -Xms1g -Xmx8g Glonass < ./data/test3_hi_precision.in; t=`date +%s.%N`; awk 'BEGIN{printf"wtime %.4f\n", 1000*('$t' - '$f')}'; done|grep '^wtime'|awk 'BEGIN{min=5000; max=0}{w=$2; s+=w; cnt+=1; if (w<min)min=w; if (w>max) max=w}END{printf"min %.3f, avg %.3f, max %.3f (ms)\n",min, s/cnt, max}'
*/
