//@dwin

import java.io.*;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Scanner;

// http://habrahabr.ru/company/wayray/blog/222279/

public class GlonassContest {

    static private final int SEQ_LENGTH = 1000000;
    static private final int FILE_SEQ_LENGTH = SEQ_LENGTH * 10;

    /**
     * Радиус "Земли" - помогает опеределить стартовый сдвиг для быстрого поиска нужной
     * последовательности.
     */
    static private final double EARTH_RADIUS = 6378000.;
    /** Расстояние одного бита переданного сигнала. */
    static private final double SHIFT_METERS = 299792458. / 1000000. / 10.;

    /**
     * Минимально возможная "магиеская" последовательность первых бит, которые передаются
     * спутниками.
     */
    static private final byte[] MAGIC = "111001100011101101".getBytes();
    static private final int PRECISE_MAGIC_START = 29;
    static private final byte PRECISE_MAGIC_SEEK = '1';

    static private final int BUF_SIZE = 131072;
    static private final int MAX_SEEK = BUF_SIZE - MAGIC.length * 10;

    Sat[] sats;

    private InputStream in = System.in;

    public static void main(String[] args) throws Exception {
//        long t0 = System.currentTimeMillis();
        new GlonassContest().go();
//        long t1 = System.currentTimeMillis();
//        System.out.println("-----\nTotal time:" + (t1 - t0));
    }

    private void go() throws Exception {
        byte[] numBuffer = new byte[128];
        byte[] buf = new byte[BUF_SIZE];

        in.read(numBuffer);
        Scanner scan = new Scanner(new ByteArrayInputStream(numBuffer));
        sats = new Sat[scan.nextInt()];

        for (int satIdx = 0; satIdx < sats.length; satIdx++) {
            if (satIdx != 0) {
                in.read(numBuffer);
                scan = new Scanner(new ByteArrayInputStream(numBuffer));
            }
            double x = scan.nextDouble();
            double y = scan.nextDouble();
            final Sat sat = sats[satIdx] = new Sat(x, y);
            final long seqPos = -scan.next().length();
            int shift = seek(buf, seqPos, sat);
            sat.setShiftTime(shift);
        }

        Point point = calcAllCoordsPoly();
        System.out.println(point.x + " " + point.y);
    }

    /**
     * Читаем входящий поток и сразу же пытаемся найти "магическую" комбинацию. Как только
     * комбинация найдена - пропускаем оставшиеся байты до конца последовательности в 10000000
     * байт.
     */
    private int seek(byte[] buf, long startPos, Sat sat) throws IOException {
        long fileShift = sat.getStartShift();
        long fileSkip = -startPos;
        int bufOffset = 0;

        skip(startPos + fileShift);
        fileSkip += startPos + fileShift;
        while (true) {
            in.read(buf, bufOffset, buf.length - bufOffset);
            fileSkip += buf.length - bufOffset;
            int base;
                 shift:
            for (base = 0; base < MAX_SEEK; base += 10) {
                for (int m = 0, b = base; m < MAGIC.length; m++, b += 10) {
                    if (MAGIC[m] != buf[b]) continue shift;
                }

                // precise seek
                int result = (int) (fileShift + base);
                for (int b = base + PRECISE_MAGIC_START; ; b--, result--) {
                    if (buf[b] == PRECISE_MAGIC_SEEK) break;
                }

                skip(FILE_SEQ_LENGTH - fileSkip);
                return result;
            }
            fileShift += base;
            bufOffset = buf.length - base;
            System.arraycopy(buf, base, buf, 0, bufOffset);
        }
    }

    private static double distance(double dx, double dy) {
        return Math.sqrt(dx * dx + dy * dy);
    }

    private static double lawOfCosines(double a, double b, double c) {
        return Math.acos((b * b + c * c - a * a) / (2. * b * c));
    }

    private static double side(Point p1, Point p2, Point p) {
        return Math.signum((p2.x - p1.x) * (p.y - p2.y) - (p.x - p2.x) * (p2.y - p1.y));
    }

    /**
     * Для всех возможных пар спутников составляем четырёхугольные полигоны покрытия сигнала. Далее,
     * находим пересечение всех полученных полигонов, и возвращаем центральную точку этого
     * пересечения. Она и будет являться решением задачи.
     */
    private Point calcAllCoordsPoly() {
        List<Point> lastPoly = null;
        for (int i = 0; i < sats.length - 1; i++) {
            for (int j = i + 1; j < sats.length; j++) {
                SatPair pair = new SatPair(sats[i], sats[j]);
                List<Point> points = pair.calcPolyTarget();

                lastPoly = lastPoly == null ? points : new PolyIntersect().clipPolygons(lastPoly, points);
                if (lastPoly == null || lastPoly.size() < 4)
                    throw new NoSolutionException("No intersections. i:" + i + ", j:" + j);
            }
        }
        return polyCentroid(lastPoly);
    }

    /**
     * Расчёт центроида - центральной точки полигона.
     */
    private static Point polyCentroid(List<Point> points) {
        int ln = points.size();
        double aSum = 0, cx = 0, cy = 0;
        Point p0, p1 = points.get(0);
        for (int i = 1; i <= ln; i++) {
            p0 = p1;
            p1 = points.get(i == ln ? 0 : i);
            double aItem = p0.x * p1.y - p1.x * p0.y;
            aSum += aItem;
            cx += (p0.x + p1.x) * aItem;
            cy += (p0.y + p1.y) * aItem;
        }
        return new Point(cx / 3. / aSum, cy / 3. / aSum);
    }

    private void skip(long n) throws IOException {
        do {
            long remain = in.skip(n);
            n -= remain;
        } while (n > 0);
    }

    // ------------------------------- Inner classes -------------------------------

    /** Исключение, бросаемое в случае, когда решения нет */
    static class NoSolutionException extends RuntimeException {
        public NoSolutionException(String message) {
            super(message);
        }
    }

    /**
     * Спутник - его координаты и расчитанное расстояние до цели.
     */
    static class Sat {
        double x, y;
        double distance;

        Sat(double x, double y) {
            this.x = x;
            this.y = y;
        }

        int getStartShift() {
            double distanceToZero = distance(x, y);
            return (int) ((distanceToZero - EARTH_RADIUS) / SHIFT_METERS);
        }

        void setShiftTime(int shiftTime) {
            distance = shiftTime * SHIFT_METERS;
        }
    }

    static class Point {
        final double x, y;

        Point(double x, double y) {
            this.x = x;
            this.y = y;
        }
    }

    /**
     * Пара спутников.
     */
    static class SatPair {
        final Sat s1, s2;
        final double satDistance, satAbsoluteAngle;

        SatPair(Sat s1, Sat s2) {
            this.s1 = s1;
            this.s2 = s2;
            satDistance = distance(s2.x - s1.x, s2.y - s1.y);
            satAbsoluteAngle = Math.atan2(s2.y - s1.y, s2.x - s1.x);
        }

        List<Point> calcPolyTarget() {
            Point p0 = calcPoint(s1.distance - SHIFT_METERS, s2.distance - SHIFT_METERS);
            Point p1 = calcPoint(s1.distance + SHIFT_METERS, s2.distance - SHIFT_METERS);
            Point p2 = calcPoint(s1.distance + SHIFT_METERS, s2.distance + SHIFT_METERS);
            Point p3 = calcPoint(s1.distance - SHIFT_METERS, s2.distance + SHIFT_METERS);
            return side(p0, p1, p2) > 0 ? Arrays.asList(p0, p1, p2, p3) : Arrays.asList(p0, p3, p2, p1);
        }

        private Point calcPoint(double s1Distance, double s2Distance) {
            double s1Angle = lawOfCosines(s2Distance, satDistance, s1Distance);
            double finalAngle = satAbsoluteAngle + s1Angle * Math.signum(s1.x * s2.y - s2.x * s1.y);
            double s = s1.x + Math.cos(finalAngle) * s1Distance;
            double y = s1.y + Math.sin(finalAngle) * s1Distance;
            return new Point(s, y);
        }
    }

    /**
     * Класс для расчёта пересечения полигонов.
     * Не thread-safe, т.к. меняет своё состояние.
     */
    static class PolyIntersect {
        private Point cp1, cp2, s, e;

        private boolean inside(Point p) {
            return (cp2.x - cp1.x) * (p.y - cp1.y) > (cp2.y - cp1.y) * (p.x - cp1.x);
        }

        private Point computeIntersection() {
            Point dc = new Point(cp1.x - cp2.x, cp1.y - cp2.y);
            Point dp = new Point(s.x - e.x, s.y - e.y);
            double n1 = cp1.x * cp2.y - cp1.y * cp2.x;
            double n2 = s.x * e.y - s.y * e.x;
            double n3 = 1.0 / (dc.x * dp.y - dc.y * dp.x);
            return new Point((n1 * dp.x - n2 * dc.x) * n3, (n1 * dp.y - n2 * dc.y) * n3);
        }

        List<Point> clipPolygons(List<Point> subjectPolygon, List<Point> clipPolygon) {
            List<Point> outputList = subjectPolygon;
            cp1 = clipPolygon.get(clipPolygon.size() - 1);

            for (int j = 0; j < clipPolygon.size(); j++) {
                cp2 = clipPolygon.get(j);
                List<Point> inputList = outputList;
                outputList = new ArrayList<>();
                s = inputList.get(inputList.size() - 1);

                for (int i = 0; i < inputList.size(); i++) {
                    e = inputList.get(i);
                    if (inside(e)) {
                        if (!inside(s)) {
                            outputList.add(computeIntersection());
                        }
                        outputList.add(e);
                    } else if (inside(s)) {
                        outputList.add(computeIntersection());
                    }
                    s = e;
                }
                cp1 = cp2;
            }
            return outputList;
        }
    }
}
