//@jenek
//package com.evgeniy;

import java.io.*;
import java.util.*;
import java.util.concurrent.*;
import java.security.MessageDigest;

class Vector2 {
    public double x;
    public double y;

    Vector2() {}

    Vector2(double x, double y) {
        this.x = x;
        this.y = y;
    }

    public void rotate(double radians) {
        double nx = x * Math.cos(radians) - y * Math.sin(radians);
        double ny = x * Math.sin(radians) + y * Math.cos(radians);
        x = nx;
        y = ny;
    }

    public void add(Vector2 v) {
        x += v.x;
        y += v.y;
    }

    public double sqLength() {
        return x * x + y * y;
    }

    static Vector2 diff(Vector2 v1, Vector2 v2) {
        return new Vector2(v1.x - v2.x, v1.y - v2.y);
    }

    static double dotProduct(Vector2 v1, Vector2 v2) {
        return v1.x * v2.x + v1.y * v2.y;
    }

    static double dist(Vector2 v1, Vector2 v2) {
        return Math.sqrt((v2.x - v1.x) * (v2.x - v1.x) + (v2.y - v1.y) * (v2.y - v1.y));
    }
}

class Circle extends Vector2 {
    public double radius;
}

class Satellite extends Circle {
    public char[] buffer;
}

class LongestSequenceResult {
    public int length;
    public int index;
    public int signal;
}

class LongestSequenceCallable implements Callable<LongestSequenceResult>
{
    static final int sequenceCoefficient = 10;

    private int start;
    private int count;
    private int totalCount;

    LongestSequenceCallable(int start, int count, int totalCount) {
        this.start = start;
        this.count = count;
        this.totalCount = totalCount;
    }

    private byte[] getBytesFast(String str) {
        final char buffer[] = new char[str.length()];
        final int length = str.length();
        str.getChars(0, length, buffer, 0);
        final byte b[] = new byte[length];
        for (int j = 0; j < length; j++) {
            b[j] = (byte) buffer[j];
        }
        return b;
    }

    private int signal(MessageDigest messageDigest, String seed, int pos) {
        String data = seed + Integer.toString(pos);
//        byte[] digest = messageDigest.digest(data.getBytes());
        byte[] digest = messageDigest.digest(getBytesFast(data));
        char checkNumber = (char)(digest[0] & 0xF0);
        return checkNumber > 0x70 ? 1 : 0;
    }

    public LongestSequenceResult call() throws Exception {

        MessageDigest messageDigest = MessageDigest.getInstance("MD5");
        String seed = "3.1415926535897932384626433832795028841971693993751058209749445923078164062862089986280348253421170679821480865132823066470938446";

        int longestLength = 0;
        int longestIndex = 0;
        int longestSignal = 0;

        int currentLength = 0;
        int currentIndex = 0;

        int prevSignal = Integer.MAX_VALUE;
        int i;
        for (i = start; i < totalCount; i++) {
            int sig = signal(messageDigest, seed, i);
            if (prevSignal == sig) {
                ++currentLength;
            } else {
                if (currentLength > longestLength) {
                    longestLength = currentLength;
                    longestIndex = currentIndex;
                    longestSignal = prevSignal;
                }

                currentIndex = i;
                currentLength = 1;

                prevSignal = sig;

                // по count завершаем поиск только вместе с концом последовательности
                if (!(i < start + count)) {
                    break;
                }
            }
        }

        LongestSequenceResult result = new LongestSequenceResult();
        result.length = longestLength * sequenceCoefficient;
        result.index = longestIndex * sequenceCoefficient;
        result.signal = longestSignal;
        return result;
    }
}

public class Main {

    static double receiverMaxDistance = 6378000;
    static double bitrate = 10000000;
    static double lightSpeed = 299792458;

    private static double calculateSatelliteRadius(char[] buffer, final LongestSequenceResult longestSubsequenceParams) {
        int rawOffset = 0;
        int seqLength = 0;
        char signalChar = longestSubsequenceParams.signal == 1 ? '1' : '0';
        for (int i = 0; i < buffer.length; i++) {
            if (buffer[i] == signalChar) {
                seqLength++;
            } else {
                seqLength = 0;
            }

            if (seqLength == longestSubsequenceParams.length) {
                rawOffset = i - seqLength; //!!!! тут +1 вроде как нужен, но на тестовом примере снижает точность
            }
        }

        int offset = rawOffset - longestSubsequenceParams.index;
        double offsetTime = offset / bitrate;
        return offsetTime * lightSpeed;
    }

    private static ExecutorService prepareSequenceStart(ArrayList<Future<LongestSequenceResult>> futures) throws InterruptedException, ExecutionException {
        int totalCount = 1000000;
        int threadsCount = Runtime.getRuntime().availableProcessors(); /// !!!
        int countForOneThread = totalCount / threadsCount;

        ExecutorService executorService = Executors.newFixedThreadPool(threadsCount);

        for (int i = 0; i < threadsCount; i++) {
            futures.add(executorService.submit(new LongestSequenceCallable(countForOneThread * i, countForOneThread, totalCount)));
        }

        return executorService;
    }

    private static LongestSequenceResult prepareSequenceComplete(ExecutorService executorService, ArrayList<Future<LongestSequenceResult>> futures) throws InterruptedException, ExecutionException {
        executorService.shutdown();
        executorService.awaitTermination(5, TimeUnit.SECONDS);

        LongestSequenceResult longestSubsequenceParams = new LongestSequenceResult();

        for(Future<LongestSequenceResult> future : futures){
            LongestSequenceResult sequenceResult = future.get();
            if (sequenceResult.length > longestSubsequenceParams.length) {
                longestSubsequenceParams = sequenceResult;
            }
        }

        return longestSubsequenceParams;
    }

    private static Vector2 trilateration(Circle c1, Circle c2, Circle c3) {
        // сдвигаем окружности чтобы начало координат было в центре первой
        Vector2 tmpC2 = Vector2.diff(c2, c1);
        Vector2 tmpC3 = Vector2.diff(c3, c1);

        double tmpSlide = Math.sqrt(Math.pow(tmpC2.x, 2) + Math.pow(tmpC2.y, 2));

        double rotation = Math.acos(Math.abs(tmpC2.x) / Math.abs(tmpSlide));

        if (tmpC2.x > 0 && tmpC2.y > 0) {
            rotation = 2 * Math.PI - rotation;
        } else if (tmpC2.x < 0 && tmpC2.y > 0) {
            rotation = Math.PI + rotation;
        } else if(tmpC2.x < 0 && tmpC2.y < 0) {
            rotation = Math.PI - rotation;
        } else if(tmpC2.x > 0 && tmpC2.y < 0) {
            rotation = rotation;
        }

        tmpC2.rotate(rotation);
        tmpC3.rotate(rotation);

        double x = (Math.pow(c1.radius, 2) - Math.pow(c2.radius, 2) + Math.pow(tmpC2.x, 2)) / (2 * tmpC2.x);
        double y = (Math.pow(c1.radius, 2) - Math.pow(c3.radius, 2) - Math.pow(x, 2) + Math.pow(x - tmpC3.x, 2) + Math.pow(tmpC3.y, 2)) / (2 * tmpC3.y);

        Vector2 result = new Vector2(x, y);
        result.rotate(- rotation);
        result.add(c1);
        return result;
    }

    private static class CrossResult
    {
        int count;
        Vector2 pos1;
        Vector2 pos2;
    }

    private static CrossResult getCrossPoints(Circle c1, Circle c2, double delta) {
        CrossResult result = new CrossResult();

        double d = Vector2.dist(c1, c2);
        if (Math.abs(d - Math.abs(c1.radius - c2.radius)) < delta / 2) {
            double nSign = Math.signum(c1.radius - c2.radius);
            double nDelta = (d - Math.abs(c1.radius - c2.radius)) / 2;
            result.count = 1;
            result.pos1 = new Vector2(c1.x + (c1.radius - nDelta) * (c2.x - c1.x) / d * nSign,
                    c1.y + (c1.radius - nDelta) * (c2.y - c1.y) / d * nSign);
        } else if (Math.abs(d - (c1.radius + c2.radius)) < delta / 2) {
            result.count = 1;
            double nDelta = (d - Math.abs(c1.radius + c2.radius)) / 2;
            result.pos1 = new Vector2(c1.x + (c1.radius + nDelta) * (c2.x - c1.x) / d,
                    c1.y + (c1.radius + nDelta) * (c2.y - c1.y) / d);
        } else if (d < c1.radius + c2.radius && d > Math.abs(c1.radius - c2.radius)) {
            result.count = 2;
            double b = (c2.radius * c2.radius - c1.radius * c1.radius + d * d) / (2 * d);
            double a = d - b;
            double h = Math.sqrt(c1.radius * c1.radius - a * a);
            Vector2 pos0 = new Vector2(c1.x + a / d * (c2.x - c1.x), c1.y + a / d * (c2.y - c1.y));
            result.pos1 = new Vector2(pos0.x + h / d * (c2.y - c1.y), pos0.y - h / d * (c2.x - c1.x));
            result.pos2 = new Vector2(pos0.x - h / d * (c2.y - c1.y), pos0.y + h / d * (c2.x - c1.x));
        }

        return result;
    }

    private static Satellite[] loadSatellites() throws IOException {
        int satelliteDataSize = 10000000;
        BufferedReader inReader = new BufferedReader(new InputStreamReader(System.in), 50000000);
        int satellitesCount = Integer.parseInt(inReader.readLine());

        Satellite[] satellites = new Satellite[satellitesCount];
        for (int satelliteIndex = 0; satelliteIndex < satellitesCount; satelliteIndex++) {
            Satellite sat = new Satellite();
            sat.x = Double.parseDouble(inReader.readLine());
            sat.y = Double.parseDouble(inReader.readLine());

            sat.buffer = new char[satelliteDataSize];
            inReader.read(sat.buffer, 0, satelliteDataSize);
            inReader.readLine();

            satellites[satelliteIndex] = sat;
        }

        return satellites;
    }

    private static void calculateSatellitesRadius(Satellite[] satellites, final LongestSequenceResult longestSubsequenceParams) throws InterruptedException {

        ExecutorService executorService = Executors.newFixedThreadPool(Runtime.getRuntime().availableProcessors());
        for (final Satellite sat : satellites) {
            executorService.submit(new Runnable() {
                public void run() {
                    synchronized (sat) {
                        sat.radius = calculateSatelliteRadius(sat.buffer, longestSubsequenceParams);
                    }
                }
            });
        }
        executorService.shutdown();
        executorService.awaitTermination(5, TimeUnit.SECONDS);
    }

    private static Vector2 calculatePosition(Satellite[] satellites) throws ExecutionException, InterruptedException {
        Vector2 result = null;

        if (satellites.length < 3) {
            CrossResult crossResult = getCrossPoints(satellites[0], satellites[1], 10);

            if (crossResult.count == 2) {
                // два результата, возьмем удовлетворяющий условию расстояния
                Vector2 zero = new Vector2(0, 0);
                double distance1 = Vector2.dist(zero, crossResult.pos1);
                if (distance1 <= receiverMaxDistance) {
                    result = crossResult.pos1;
                } else {
                    double distance2 = Vector2.dist(zero, crossResult.pos2);
                    if (distance2 <= receiverMaxDistance) {
                        result = crossResult.pos2;
                    }
                }
            } else if (crossResult.count == 1) {
                result = crossResult.pos1;
            }
        } else if (satellites.length == 3) {
            result = trilateration(satellites[1], satellites[2], satellites[3]);
        } else {
            result = trilaterationAverage(satellites);
        }

        return result;
    }

    private static Vector2  trilaterationAverage(final Satellite[] satellites) throws ExecutionException, InterruptedException {
        int threadsCount = Runtime.getRuntime().availableProcessors();
        ExecutorService executorService = Executors.newFixedThreadPool(threadsCount);

        Set<Callable<double[]>> callables = new HashSet<Callable<double[]>>();

        for (int i = 0; i < threadsCount; i++) {
            callables.add(new Callable<double[]>() {
                @Override
                public double[] call() throws Exception {
                    Satellite[] threadSatellites = satellites.clone();

                    // тут бы попробовать мультилатерацию
                    // но пока возьмем усредненную трилатерацию
                    List<Satellite> satellitesList = Arrays.asList(threadSatellites);

                    double totalX = 0;
                    double totalY = 0;
                    double totalWeight = 0;
                    int satellitesCount = satellitesList.size();

                    for (int i = 0; i < 100; i++) {
                        // трясем мешок со спутниками и вычисляем трилатерации и уровень их качества равный площади треугольника
                        Collections.shuffle(satellitesList);

                        for (int a = 0; a < satellitesCount; a++) {
                            int b = a + 1;
                            if (b >= satellitesCount) b -= satellitesCount;
                            int c = a + 2;
                            if (c >= satellitesCount) c -= satellitesCount;

                            double weight = satellitesTripletWeight(satellitesList.get(a), satellitesList.get(b), satellitesList.get(c));
                            Vector2 v = trilateration(satellitesList.get(a), satellitesList.get(b), satellitesList.get(c));
                            totalX += v.x * weight;
                            totalY += v.y * weight;
                            totalWeight += weight;
                        }
                    }

                    return new double[]{totalX, totalY, totalWeight};
                }
            });
        }

        List<Future<double[]>> futures = executorService.invokeAll(callables);
        executorService.shutdown();

        double totalX = 0;
        double totalY = 0;
        double totalWeight = 0;
        for(Future<double[]> future : futures){
            double[] result = future.get();
            totalX += result[0];
            totalY += result[1];
            totalWeight += result[2];
        }

        return new Vector2(totalX / totalWeight, totalY / totalWeight);
    }

    private static double satellitesTripletWeight(Vector2 v1, Vector2 v2, Vector2 v3)
    {
        // площадь треугольника
        Vector2 a = Vector2.diff(v2, v1);
        Vector2 b = Vector2.diff(v3, v1);
        double z = Math.sqrt( a.sqLength() * b.sqLength() );
        double cos = Vector2.dotProduct(a, b) / z;
        return z * (1 - cos * cos);
    }



    public static void main(String[] args) {
        try {
            // запускаем поиск опорной последовательности в фоне
            ArrayList<Future<LongestSequenceResult>> futures = new ArrayList<Future<LongestSequenceResult>>();
            ExecutorService executorService = prepareSequenceStart(futures);

            Satellite[] satellites = loadSatellites();

            // объединяем разультаты поиска опорной последовательности
            LongestSequenceResult longestSubsequenceParams =  prepareSequenceComplete(executorService, futures);

            calculateSatellitesRadius(satellites, longestSubsequenceParams);

            Vector2 position = calculatePosition(satellites);

            System.out.println(position.x + " " + position.y); // выдача результата, не удалять
        } catch (Exception exception) {
            exception.printStackTrace();
        }
    }
}

