//@taviscaron
//package net.taviscaron.glonass;

import java.io.*;
import java.util.*;
import java.util.concurrent.*;

/**
 * Glonass GNSS system
 * @author Andrei Senchuk
 */
public class Glonass {
    private static final int SATELLITE_DISTANCE_MIN = 10_000_000;
    private static final int SATELLITE_DISTANCE_MAX = 20_000_000;
    private static final int RECEIVER_DISTANCE_MAX = 6_378_000;
    private static final int SPEED_Of_LIGHT_MPS = 299_792_458;
    private static final int RECEIVING_SPEED_BPS = 10_000_000;
    private static final int DEVIATION = 1000;
    private static final int UNIQ_BITS_SIZE = 180;
    private static final BitSet UNIQ_BITS_SET = BitSet.valueOf(new long[] {0xfffc00003fffffffL, 0xfffffff00000003fL, 0x000ffc00fffff003L});

    private static final ExecutorService executor = Executors.newCachedThreadPool();

    /** Point representation in 2D coordinates X;Y */
    private static class Point {
        public final double x;
        public final double y;

        public Point(double x, double y) {
            this.x = x;
            this.y = y;
        }

        public double distance() {
            return Math.sqrt(x * x + y * y);
        }

        public String toString() {
            return String.format(Locale.US, "%e %e", x, y);
        }
    }

    /** Satellite info */
    private static class Satellite {
        public final Point location;
        private final BitSet sequence;
        private final int seqSize;
        private Future<Double> distance;

        public Satellite(Point location, BitSet sequence, int seqSize) {
            this.location = location;
            this.sequence = sequence;
            this.seqSize = seqSize;
            this.distance = executor.submit(new Callable<Double>() {
                @Override
                public Double call() throws Exception {
                    return defineDistance();
                }
            });
        }

        public double distance() {
            try {
                return distance.get();
            } catch (InterruptedException | ExecutionException e) {
                throw new RuntimeException(e);
            }
        }

        private double defineDistance() {
            boolean finished = false;
            int shift = 0;
            while(!finished && shift < seqSize - 1) {
                finished = true;
                for(int i = 0; i < UNIQ_BITS_SIZE; i++) {
                    if(UNIQ_BITS_SET.get(i) != sequence.get((i + shift) % seqSize)) {
                        shift++;
                        finished = false;
                        break;
                    }
                }
            }

            if(finished) {
                return (double)shift / RECEIVING_SPEED_BPS * SPEED_Of_LIGHT_MPS;
            } else {
                throw new RuntimeException("Cant find uniq seq");
            }
        }
    }

    private static class Parser {
        private final InputStream is;
        private byte[] buffer = new byte[20 * 1024];
        private int size = 0;
        private int pointer = 0;

        public Parser(InputStream is) {
            this.is = is;
        }

        public int readIntLine() throws IOException {
            skipSpaces();

            int val = 0;
            while(true) {
                int ch = read();
                if(ch >= '0' && ch <= '9') {
                    val = val * 10 + ch - '0';
                } else {
                    break;
                }
            }

            return val;
        }

        public double readDoubleLine() throws IOException {
            skipSpaces();

            StringBuilder sb = new StringBuilder();
            while(true) {
                int ch = read();
                if(ch != '\n' && ch != '\r' && ch != ' ' && ch != '\t') {
                    sb.append((char)ch);
                } else {
                    break;
                }
            }

            return Double.parseDouble(new String(sb));
        }

        public int readBitsLine(BitSet set) throws IOException {
            skipSpaces();

            int pos = 0;
            while(true) {
                int ch = read();
                if(ch == '1' || ch == '0') {
                    set.set(pos++, ch == '1');
                } else {
                    break;
                }
            }

            return pos;
        }

        private void skipSpaces() throws IOException {
            while (true) {
                int ch = read();
                if(ch != '\n' && ch != '\r' && ch != ' ' && ch != '\t') {
                    pointer--;
                    break;
                }
            }
        }

        private int read() throws IOException {
            if(pointer >= size) {
                pointer = 0;
                size = is.read(buffer);
            }
            return buffer[pointer++];
        }
    }

    public Point localize(List<Satellite> satellites) {
        Iterator<Satellite> satelliteIterator = satellites.iterator();
        while(satelliteIterator.hasNext()) {
            final Satellite s = satelliteIterator.next();

            double distance = s.location.distance();
            if(distance < SATELLITE_DISTANCE_MIN || distance > SATELLITE_DISTANCE_MAX) {
                satelliteIterator.remove();
            }
        }

        List<Point> pretends = new ArrayList<>(satellites.size());
        for(int i = 0; i < satellites.size(); i++) {
            for(int j = i + 1; j < satellites.size(); j++) {
                Satellite s1 = satellites.get(i);
                Satellite s2 = satellites.get(j);
                Point[] points = pretends(s1.location, s1.distance(), s2.location, s2.distance());
                for(Point p : points) {
                    if(p.distance() <= RECEIVER_DISTANCE_MAX) {
                        pretends.add(p);
                    }
                }
            }
        }

        boolean[][] matrix = new boolean[pretends.size()][pretends.size()];
        for(int i = 0; i < pretends.size(); i++) {
            for(int j = i + 1; j < pretends.size(); j++) {
                Point p1 = pretends.get(i);
                Point p2 = pretends.get(j);
                double distance = Math.sqrt(Math.pow(p1.x - p2.x, 2) + Math.pow(p1.y - p2.y, 2));
                matrix[i][j] = distance < DEVIATION;
            }
        }

        int pos = 0;
        int max = 0;
        for(int i = 0; i < matrix.length; i++) {
            int count = 0;
            for(boolean b : matrix[i]) {
                count += b ? 1 : 0;
            }

            if(count > max) {
                max = count;
                pos = i;
            }
        }

        List<Point> clusterized = new ArrayList<>(max + 1);

        clusterized.add(pretends.get(pos));
        for(int i = 0; i < matrix[pos].length; i++) {
            if(matrix[pos][i]) {
                clusterized.add(pretends.get(i));
            }
        }

        if(clusterized.size() == 1) {
            return clusterized.get(0);
        } else if(clusterized.size() == 0) {
            throw new RuntimeException("Distance is too long");
        } else {
            return expectedPoint(clusterized);
        }
    }

    private Point expectedPoint(List<Point> points) {
        double x = 0;
        double y = 0;
        for(Point p : points) {
            x += p.x;
            y += p.y;
        }
        return new Point(x / points.size(), y / points.size());
    }

    private Point[] pretends(Point p0, double d0, Point p1, double d1) {
        double R0 = d0 * d0;
        double R1 = d1 * d1;
        double k = (p1.y - p0.y) / (p1.x - p0.x);
        double u = (R0 - R1 - p0.x * p0.x - p0.y * p0.y + p1.x * p1.x + p1.y * p1.y) / (p1.x - p0.x) / 2;
        double s = k * k + 1;
        double v = 2 * ((u - p0.x) * k + p0.y);
        double D = v * v - 4 * s * (Math.pow(u - p0.x, 2) + p0.y * p0.y - R0);

        double y1 = (v + Math.sqrt(D)) / 2 / s;
        double x1 = u - k * y1;

        double y2 = (v - Math.sqrt(D)) / 2 / s;
        double x2 = u - k * y2;

        return new Point[] {
                new Point(x1, y1),
                new Point(x2, y2)
        };
    }

    public static void main(String[] args) throws IOException {
        try(InputStream is = (args.length > 0) ? new FileInputStream(args[0]) : System.in) {
            Parser parser = new Parser(is);

            int count = parser.readIntLine();
            List<Satellite> satellites = new ArrayList<>(count);

            for(int i = 0; i < count; i++) {
                double x = parser.readDoubleLine();
                double y =  parser.readDoubleLine();
                Point p = new Point(x, y);

                BitSet seq = new BitSet();
                int size = parser.readBitsLine(seq);

                satellites.add(new Satellite(p, seq, size));
            }

            Glonass glonass = new Glonass();
            Point point = glonass.localize(satellites);
            System.out.println(point);
        }

        executor.shutdown();
    }
}
