//@where-is-s
import java.io.IOException;
import java.io.InputStream;
import java.util.LinkedList;
import java.util.List;
import java.util.concurrent.BlockingQueue;
import java.util.concurrent.LinkedBlockingQueue;
import java.util.concurrent.ThreadPoolExecutor;
import java.util.concurrent.TimeUnit;

public class Solution {
	static final byte START[] = "111001100011101101".getBytes(); // shortest unique start sequence
	static final int MAX_POWER = 131072; // 2^START.length, needed for running hash calculation
	static final int SEQ_LENGTH = 10000000;
	static final double SAMPLE_DURATION = 1./10000000;
	static final int SAMPLES_PER_BIT = 10;
	static final double SPEED_OF_LIGHT = 299792458.;

	static int getHash(byte[] buf, int len, int step, int offset) {
		int hash = 0;
		for (int i = 0; i < len; ++i)
			hash = 2*hash + buf[offset + i * step];
		return hash;
	}

	static int findStart(byte[] buf, int step, int offset) {
		int hash = getHash(buf, START.length, step, offset);
		int shash = getHash(START, START.length, 1, 0);
		for (int i = 0, n = (buf.length - offset)/step - START.length; i <= n; ++i) {
			if (hash == shash)
				return i;
			hash = 2*(hash - buf[offset + i*step] * MAX_POWER) + buf[offset + (i + START.length)*step];
		}
		return -1;
	}

	static int findSignalOffset(byte[] buf, int dataOffset) {
		int pos = dataOffset;
		byte initial = buf[pos];
		while (buf[++pos] == initial);
		return (pos - dataOffset) % 10;
	}

	static class ByteArrayLineReader {
		int pos = 0;
		byte array[];

		ByteArrayLineReader(byte array[]) {
			this.array = array;
		}

		String readLine() {
			StringBuilder builder = new StringBuilder();
			while (array[pos] != 13 && array[pos] != 10)
				builder.append((char) array[pos++]);
			skipLineEnd();
			return builder.toString();
		}

		void skipLineEnd() {
			while (array[pos] == 13 || array[pos] == 10)
				++pos;
		}

		int getPos() {
			return pos;
		}
	}

	static class Satellite {
		double x;
		double y;
		double minDist;
		double maxDist;
	}

	static class Point {
		public Point(double x, double y) {
			this.x = x;
			this.y = y;
		}
		public double dist2(Point p2) {
			return (p2.x-x)*(p2.x-x) + (p2.y-y)*(p2.y-y);
		}
		double x;
		double y;
	}

	static class Calculator extends Thread {
		List<Satellite> satellites = new LinkedList<Satellite>();
		BlockingQueue<Satellite> satellitesQueue = new LinkedBlockingQueue<Satellite>();
		Point result;
		volatile boolean stopped = false;
		volatile boolean readingStopped = false;

		boolean findSimpleMatch(Point p) {
			int iter = 0;
			int count = satellites.size();
			int iterations = count * 20;
			Point prev = new Point(0, 0);
			boolean match = false;
			do {
				Satellite sat = satellites.get(iter++ % count);
				double vx = p.x - sat.x;
				double vy = p.y - sat.y;
				double curDist = Math.sqrt(vx*vx + vy*vy);
				prev.x = p.x;
				prev.y = p.y;
				double jump = iter > (iterations/2) ? 0.1 : ((sat.maxDist - sat.minDist) / 2);
				if (curDist < sat.minDist) {
					p.x = sat.x + vx / curDist * (sat.minDist + jump);
					p.y = sat.y + vy / curDist * (sat.minDist + jump);
				} else if (curDist > sat.maxDist) {
					p.x = sat.x + vx / curDist * (sat.maxDist - jump);
					p.y = sat.y + vy / curDist * (sat.maxDist - jump);
				}
				if (p.dist2(prev) < 1)
					match = checkMatch(p);
			} while (!match && iter < iterations);
			return match;
		}

		int checkMatches = 0;
		boolean checkMatch(Point p) {
			++checkMatches;
			for (Satellite sat: satellites) {
				double vx = p.x - sat.x;
				double vy = p.y - sat.y;
				double curDist = Math.sqrt(vx*vx + vy*vy);
				if (curDist < sat.minDist || curDist > sat.maxDist)
					return false;
			}
			return true;
		}

		int traverseAreaLine(double startx, double starty, double stepSize, int stepCount, Point sum) {
			boolean checkLeft = true, checkRight = true, leftFound = false, rightFound = false;
			int cc = 0;
			for (double dx = stepSize; dx < stepCount*stepSize; dx += stepSize) {
				if (!checkLeft && !checkRight)
					break;
				if (dx > stepSize*stepCount/2 && !leftFound && !rightFound)
					break;
				if (checkLeft) {
					Point p = new Point(startx - dx, starty);
					if (checkMatch(p)) {
						leftFound = true;
						sum.x += p.x;
						sum.y += p.y;
						++cc;
					} else if (leftFound || rightFound)
						checkLeft = false;
				}
				if (checkRight) {
					Point p = new Point(startx + dx, starty);
					if (checkMatch(p)) {
						rightFound = true;
						sum.x += p.x;
						sum.y += p.y;
						++cc;
					} else if (leftFound || rightFound)
						checkRight = false;
				}
			}
			return cc;
		}

		int findAreaCenter(Point point, double stepSize, int stepCount) {
			Point sum = new Point(point.x, point.y);
			int sumPoints = 1;
			boolean checkUp = true, checkDown = true;
			for (double dy = stepSize; dy < stepCount*stepSize; dy += stepSize) {
				if (!checkUp && !checkDown)
					break;
				if (checkUp) {
					int line = traverseAreaLine(point.x, point.y + dy, stepSize, stepCount, sum);
					sumPoints += line;
					if (line == 0)
						checkUp = false;
				}
				if (checkDown) {
					int line = traverseAreaLine(point.x, point.y - dy, stepSize, stepCount, sum);
					sumPoints += line;
					if (line == 0)
						checkDown = false;
				}
			}
			point.x = sum.x / sumPoints;
			point.y = sum.y / sumPoints;
			return sumPoints;
		}

		@Override
		public void run() {
			while (!stopped && (!readingStopped || !satellitesQueue.isEmpty())) {
				if (satellitesQueue.isEmpty()) {
					try {
						Thread.sleep(1);
					} catch (InterruptedException e) {}
					continue;
				}

				satellitesQueue.drainTo(satellites);

				if (satellites.size() < 2)
					continue;

				result = new Point(0, 0);
				boolean goodMatch = findSimpleMatch(result);
				double stepSize = 5;
				double areaSize = findAreaCenter(result, stepSize, 100);
				double avgDelta = stepSize * Math.sqrt(areaSize) / 2;

				if (goodMatch && areaSize > 1 && avgDelta < 10) { // non-empty area with good accuracy
					stopped = true;
					return;
				}
			}
		}
	}

	public static void main(String args[]) throws IOException {
		InputStream is = System.in;

		ThreadPoolExecutor executor = new ThreadPoolExecutor(2, 2, 1, TimeUnit.MINUTES, new LinkedBlockingQueue<Runnable>());
		final Calculator calculator = new Calculator();

		List<Point> satPoints = new LinkedList<Point>();

		int satCount = 1;
		for (int i = 0; i < satCount && !calculator.stopped; ++i) {
			// distance cannot be greater than (20000km+6378km)=26378km -> max time = 0.088s -> max offset = 880kb
			final byte buffer[] = new byte[900000];
			is.read(buffer);
			ByteArrayLineReader reader = new ByteArrayLineReader(buffer);
			if (i == 0) {
				satCount = Integer.valueOf(reader.readLine());
			} else
				reader.skipLineEnd();

			Point newSatPoint = new Point(Double.valueOf(reader.readLine()),
					Double.valueOf(reader.readLine()));

			boolean badSat = false;
			if (satCount > 5 && i > 3) { // if there are many satellites & we already got at least three, ignore closely standing ones
				for (Point sp: satPoints)
					if (sp.dist2(newSatPoint) < 1e12) { // 1000 km = 1e6 m
						badSat = true;
						break;
					}
			}

			final int dataStartPos = reader.getPos();
			int bufLeft = buffer.length - dataStartPos;
			if (i != satCount - 1)
				is.skip(SEQ_LENGTH - bufLeft); // skip the rest, increase the speed!

			if (i == 10) // do not start separate thread unless minimum 11 satellites are present
				calculator.start();

			if (badSat) {
				continue;
			} else {
				satPoints.add(newSatPoint);
			}

			final Satellite sat = new Satellite();
			sat.x = newSatPoint.x;
			sat.y = newSatPoint.y;

			Runnable satParse = new Runnable() {
				@Override
				public void run() {
					if (calculator.stopped)
						return;
					int pos = dataStartPos;
					int signalOffset = findSignalOffset(buffer, pos);
					pos += signalOffset;
					int newSignalStart = SAMPLES_PER_BIT * findStart(buffer, SAMPLES_PER_BIT, pos);
					// -1.5 & 2 were calculated from test examples though they seem to be incorrect logically
					sat.minDist = (newSignalStart + signalOffset - 1.5) * SPEED_OF_LIGHT * SAMPLE_DURATION;
					sat.maxDist = sat.minDist + 2 * SPEED_OF_LIGHT * SAMPLE_DURATION;
					calculator.satellitesQueue.add(sat);
				}
			};

			if (satCount <= 10)
				satParse.run();
			else
				executor.execute(satParse);
		}

		is.close();

		executor.shutdown();
		try {
			executor.awaitTermination(50, TimeUnit.MILLISECONDS);
		} catch (InterruptedException e) {}
		calculator.readingStopped = true;

		if (satCount <= 10)
			calculator.run();
		else {
			try {
				calculator.join(1000);
			} catch (InterruptedException e) {}
		}

		System.out.println(String.valueOf(calculator.result.x) + " " + String.valueOf(calculator.result.y));
	}
}
